# Polar Bear

<img src="https://raw.githubusercontent.com/regonn/polar_bear/master/data/polar_bear.png" width="300" />

:panda_face: -> cleansing -> polar bear!! ʕ·ᴥ·　 ʔ

[![CircleCI](https://circleci.com/gh/regonn/polar_bear.svg?style=svg)](https://circleci.com/gh/regonn/polar_bear)
[![MIT License](http://img.shields.io/badge/license-MIT-blue.svg?style=flat)](https://github.com/regonn/polar_bear/blob/master/LICENSE.txt)
[![PyPI version](https://badge.fury.io/py/polar-bear.svg)](https://badge.fury.io/py/polar-bear)
[![Python Versions](https://img.shields.io/pypi/pyversions/polar_bear.svg)](https://pypi.org/project/polar-bear/)

Polar-bear is a library for easily and quickly performing machine learning tasks. 

Example of machine learning tasks:

- Classification
- Regression

In addition, it generally performs necessary preprocessing automatically.

Example of preprocessing:

- OnehotEncoding
- Handling MissingValue
## Installation

`$ pip install polar-bear`

## Get Started

- [Tutorial Notebook](https://github.com/regonn/polar_bear/blob/master/examples/polar_bear_tutorials.ipynb)

## License
This project is licensed under the terms of the MIT license. See [LICENSE](https://github.com/regonn/polar_bear/blob/master/LICENSE.txt) for additional details.